@@ -1,5 +1,7 @@
 """Markdown files translator using PO files as reference."""
 
+import string
+
 import md4c
 import polib
 
@@ -16,7 +18,11 @@ from mdpo.po import (
     po_escaped_string,
     pofiles_to_unique_translations_dicts,
 )
-from mdpo.text import min_not_max_chars_in_a_row, parse_wrapwidth_argument
+from mdpo.text import (
+    min_not_max_chars_in_a_row,
+    parse_wrapwidth_argument,
+    unicode_linebreak_wrap,
+)
 
 
 class Po2Md:
@@ -124,7 +130,7 @@ class Po2Md:
         )
 
         #: list(str): MD4C extensions used to parse the content.
-        #: See all available in :doc:`/devref/mdpo/mdpo.md4c`.
+        #: See all available in :doc:`/dev/reference/mdpo.md4c`.
         self.extensions = kwargs.get(
             'extensions',
             DEFAULT_MD4C_GENERIC_PARSER_EXTENSIONS,
@@ -247,7 +253,10 @@ class Po2Md:
             self._leavespan_replacer[md4c.SpanType.WIKILINK.value] = \
                 self.wikilink_end_string
 
-        self._inside_htmlblock = False
+        self._inside_htmlblock = [
+            False,  # the parser is inside an HTML block
+            None,  # a mdpo command has been found in the HTML block
+        ]
         self._inside_codeblock = False
         self._inside_indented_codeblock = False
         self._inside_hblock = False
@@ -326,7 +335,9 @@ class Po2Md:
     def _process_command(self, text):
         original_command, comment = parse_mdpo_html_command(text)
         if original_command is None:
-            return
+            return False
+
+        self._inside_htmlblock[1] = True
 
         try:
             command = self.command_aliases[original_command]
@@ -336,6 +347,8 @@ class Po2Md:
         # process solved command
         self.command(command, comment, original_command)
 
+        return True
+
     def _escape_translation(self, text):
         if self._aimg_title_inside_current_msgid:
             # escape '"' characters inside links and image titles
@@ -431,6 +444,20 @@ class Po2Md:
                     wikilink_end_string=self.wikilink_end_string,
                 ).wrap(translation)
 
+                # Break lines with Unicode Line Break algorithm
+                #
+                # Only execute it for strings without code spans
+                # and without normal whitespace characters
+                if (
+                    self.code_end_string not in translation
+                    and self.code_start_string not in translation
+                    and not any([ws in translation for ws in string.whitespace])
+                ):
+                    translation = unicode_linebreak_wrap(
+                        translation,
+                        self.wrapwidth,
+                    )
+
                 if self._inside_hblock or self._current_thead_aligns:
                     translation = translation.rstrip('\n')
 
@@ -561,7 +588,7 @@ class Po2Md:
             if self._current_list_type and not self._inside_quoteblock:
                 self._save_current_line()
         elif block is md4c.BlockType.HTML:
-            self._inside_htmlblock = True
+            self._inside_htmlblock = [True, False]
 
     def leave_block(self, block, details):
         # raise 'leave_block' event
@@ -681,7 +708,11 @@ class Po2Md:
                 self._save_current_line()
             self._current_thead_aligns = []
         elif block is md4c.BlockType.HTML:
-            self._inside_htmlblock = False
+            if not self._inside_htmlblock[1]:
+                self.current_line += '\n'
+            else:
+                self.current_line = self.current_line.rstrip('\n')
+            self._inside_htmlblock[0] = False
 
     def enter_span(self, span, details):
         # raise 'enter_span' event
@@ -851,7 +882,7 @@ class Po2Md:
         ):
             return
 
-        if not self._inside_htmlblock:
+        if not self._inside_htmlblock[0]:
             if not self._inside_codeblock:
                 if self._inside_liblock and text == '\n':
                     text = ' '
@@ -903,7 +934,8 @@ class Po2Md:
                         self.current_line += indent
                 self.current_msgid += text
         else:
-            self._process_command(text)
+            if not self._process_command(text):
+                self.current_line += text
 
     def _append_link_references(self):
         if self.link_references:
