@@ -150,3 +150,47 @@ def parse_wrapwidth_argument(value):
             f"Invalid value '{value}' for wrapwidth argument.",
         )
     return value
+
+
+def unicode_linebreak_wrap(text, wrapwidth):
+    """Line wrapping implementation using Unicode Line Break algorithm.
+
+    Useful to correctly wrap Japanese/Chinese-like languages.
+    Uses the library unicode-linebreak, see:
+    https://pypi.org/project/unicode-linebreak/
+
+    Args:
+        text (str): Text to wrap.
+        wrapwidth (int): Wrap width.
+
+    Returns:
+        str: Wrapped text.
+    """
+    from unicode_linebreak import linebreaks
+
+    result = ''
+    _current_line = ''
+    _current_line_start_index = 0
+
+    breaks = linebreaks(text)
+    for i, (index, is_mandatory_break) in enumerate(breaks):
+        _current_line = text[_current_line_start_index:index]
+        try:
+            _line_length_at_next_break = len(
+                text[_current_line_start_index:breaks[i + 1][0] - 1],
+            )
+        except IndexError:  # last line break (mandatory)
+            _line_length_at_next_break = 0
+
+        if is_mandatory_break:
+            result += _current_line.strip()
+            _current_line = ''
+            _current_line_start_index = index
+        elif _line_length_at_next_break >= wrapwidth:
+            result += _current_line[:-1].strip()
+            if '\n' not in _current_line and '\r' not in _current_line:
+                result += '\n'
+            _current_line = ''
+            _current_line_start_index = index - 1
+
+    return result
